@@ -71,6 +71,8 @@ def start_server(debug = False):
                     #conn.send(pickle.dumps(size))
 
                     data = conn.recv(int(size.decode("utf-8")))
+                    if debug == True:
+                        print ('Data received from client')
 
                     code = pickle.loads(data)
                     block = '\n'.join(code.splitlines()[:-1])
@@ -91,10 +93,9 @@ def start_server(debug = False):
 
                     conn.send(pickle.dumps(resultsize))
 
-                    conn.send(result)
+                    conn.send(pickle.dumps(result))
 
-                    if debug == True:
-                        print ('Data received from client')
+                    
 
 
                 except Exception as g:
@@ -173,7 +174,7 @@ def do(code):
                 
                 try:
                     
-                    rsize = s.recv(4096)
+                    rsize = pickle.loads(s.recv(4096))
                     
                 except:
                     
@@ -182,11 +183,12 @@ def do(code):
                 
                 try:
                     
-                    result = pickle.loads(conn.recv(int(rsize.decode("utf-8"))))
+                    result = pickle.loads(s.recv(int(rsize)))
                     return result
                 
                 except:
                     
+                    
                     raise RuntimeError("Error recieving result")
                     
                 
